@@ -24,11 +24,11 @@ class Client:
     def __getattr__(self, name):
         def method(*args, **kwargs):
             if name[:4] == 'add_':
-                return self.add(name[:4] + 's', **kwargs)
+                return self.add(name[4:] + 's', **kwargs)
             elif name[:4] == 'get_':
-                return self.get(name[:4] + 's', *args, **kwargs)
+                return self.get(name[4:] + 's', *args, **kwargs)
             elif name[:7] == 'update_':
-                return self.update(name[:7] + 's', *args, **kwargs)
+                return self.update(name[7:] + 's', *args, **kwargs)
             else:
                 return getattr(self, name)(*args, **kwargs)
 
@@ -51,6 +51,14 @@ class Client:
         resp = requests.get(url, headers=self.api_headers, params=kwargs)
         return self.prepare_response(resp)
 
+    def hydra(self, func, *args, **kwargs):
+        url = f'{self.api_endpoint}/hydra/{func}'
+        resp = requests.post(url, headers=self.api_headers, json={
+            'args': args,
+            'kwargs': kwargs
+        })
+        return self.prepare_response(resp)
+
     @staticmethod
     def prepare_response(resp):
         if resp.status_code == 200:
